import React, { useEffect, useState } from "react";
import { useForm } from "react-hook-form";
import CustomTable, { Column } from "../../components/CustomTable";
import { RootState } from "../../redux/reducers";
import { useDispatch, useSelector } from "react-redux";
import { AppDispatch } from "../../redux/store/store";
import AddStationModal from "../../components/AddStationModal";
import EditStationModal from "../../components/EditStationModal";
import {
	createStation,
	stationList,
	toggleStatus,
	updateStation,
} from "../../redux/slices/stationSlice";
import { Chip, Switch } from "@mui/material";

export default function StationList() {
	const [addModalOpen, setAddModalOpen] = useState<boolean>(false);
	const [editModalOpen, setEditModalOpen] = useState<boolean>(false);
	const [editRow, setEditRow] = useState<any>(null);
	const { reset } = useForm();

	const [deleteModal, setDeleteModal] = useState<boolean>(false);
	const [viewModal, setViewModal] = useState<boolean>(false);
	const [rowData, setRowData] = useState<any | null>(null);
	const [searchTerm, setSearchTerm] = useState("");
	const dispatch = useDispatch<AppDispatch>();
	const stations = useSelector(
		(state: RootState) => state.stationReducer.stations
	);

	useEffect(() => {
		dispatch(stationList());
	}, [dispatch]);

	const handleClickOpen = () => {
		setRowData(null); // Reset row data when opening for new admin
		setAddModalOpen(true);
	};

	const handleCloseModal = () => {
		setAddModalOpen(false);
		setEditModalOpen(false);
		setRowData(null);
		reset();
	};

	const handleAddStation = async (data: {
		name: string;
		registeredAddress: string;
		totalSlots: string;
	}) => {
		try {
			await dispatch(createStation(data)); // Dispatch action to add Station
			await dispatch(stationList()); // Fetch the updated list
			handleCloseModal(); // Close the modal
		} catch (error) {
			console.error("Error adding Station", error);
		}
	};

	const handleUpdate = async (
		id: string,
		name: string,
		registeredAddress: string,
		totalSlots: string
	) => {
		try {
			await dispatch(
				updateStation({
					id,
					name,
					registeredAddress,
					totalSlots,
					
				})
			);
			await dispatch(stationList());
			handleCloseModal();
		} catch (error) {
			console.error("Update failed", error);
		}
	};

	const handleStatusToggle = async(id: string, newStatus: number) => {
	    await dispatch(toggleStatus({ id, status: newStatus }));
	
	};
	// Toggle station status
	// const handleStatusToggle = async (id: string, currentStatus: number) => {
	// 	try {
	// 		const newStatus = currentStatus === 1 ? 0 : 1; // Toggle between Active(1) and Inactive(0)
	// 		await dispatch(
	// 			updateStation({
	// 				id,
	// 				status: newStatus,
	// 				name: stations.name,
	// 				registeredAddress: stations.registeredAddress,
	// 				totalSlots: stations.totalSlots,
	// 			})
	// 		);
	// 		await dispatch(stationList());
	// 	} catch (error) {
	// 		console.error("Error toggling status", error);
	// 	}
	// };
	const filterStations = stations?.filter((station) =>
		station.name.toLocaleLowerCase().includes(searchTerm.toLowerCase())
	);

	const categoryRows = filterStations?.length
		? filterStations?.map((station: Station, index: number) => ({
				id: station.id,
				srno: index + 1,
				name: station.name,
				registeredAddress:station.registeredAddress,
				totalSlots:station.totalSlots,
				status: (
					<Chip
						label={
							station.status === 1 ? "Available" : "Not Available"
						}
						color={station.status === 1 ? "primary" : "default"}
						variant="outlined"
						sx={{
							fontWeight: 600,
							width: "80px",
							textAlign: "center",
							borderRadius: "4px",
						}}
					/>
				),
				statusValue: station.status,
		  }))
		: [];

	const categoryColumns: Column[] = [
		{ id: "srno", label: "Sr No" },
		{ id: "id", label: "Station ID" },
		{ id: "name", label: "Station Name" },
		{ id: "registeredAddress", label: "Station Location" },
		{ id: "totalSlots", label: "Total Slots" },
		//{ id: "status", label: "Status" },
		{ id: "action", label: "Action", align: "center" },
	];

	// Filter stations based on search term
	// const filterStations = stations?.filter((station) =>
	// 	station.name.toLocaleLowerCase().includes(searchTerm.toLowerCase())
	// );

	// // Prepare categoryRows with toggle switch for status
	// const categoryRows = filterStations?.length
	// 	? filterStations?.map((station: any, index: number) => ({
	// 			id: station.id,
	// 			srno: index + 1,
	// 			name: station.name,
	// 			status: (
	// 				<Switch
	// 					checked={station.status === 1}
	// 					onChange={() =>
	// 						handleStatusToggle(station.id, station.status)
	// 					}
	// 					color="primary"
	// 					inputProps={{ "aria-label": "station-status-toggle" }}
	// 				/>
	// 			),
	// 			statusValue: station.status,
	// 	  }))
	// 	: [];

	return (
		<>
			<CustomTable
				columns={categoryColumns}
				rows={categoryRows}
				setDeleteModal={setDeleteModal}
				deleteModal={deleteModal}
				setViewModal={setViewModal}
				viewModal={viewModal}
				setRowData={setRowData}
				setModalOpen={() => setEditModalOpen(true)}
				handleStatusToggle={handleStatusToggle}
				tableType="station"
				handleClickOpen={handleClickOpen}
			/>
			<AddStationModal
				open={addModalOpen}
				handleClose={handleCloseModal}
				handleAddStation={handleAddStation}
			/>
			<EditStationModal
				open={editModalOpen}
				handleClose={handleCloseModal}
				handleUpdate={handleUpdate}
				editRow={rowData}
			/>
		</>
	);
}
